@@ -218,6 +218,10 @@ func (c *Config) runInitCmd(cmd *cobra.Command, args []string) error {
 
 // builtinGitClone clones a repo using the builtin git command.
 func (c *Config) builtinGitClone(username, url string, workingTreeRawPath chezmoi.AbsPath) error {
+	if c.init.ssh {
+		return errors.New("builtin git does not support cloning repos over ssh, please install git")
+	}
+
 	isBare := false
 	var referenceName plumbing.ReferenceName
 	if c.init.branch != "" {
